@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2015 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2015-2016 Mir Calculate. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -22,10 +22,10 @@ from calculate.lib.utils.files import FilesError
 from calculate.lib.variables.system import RootType
 from calculate.update.emerge_parser import EmergeError
 from calculate.update.update import UpdateError
-from ..datavars import BuilderError
 from calculate.lib.utils.git import GitError
 from calculate.install.distr import DistributiveError
-from calculate.builder.variables.action import Actions
+from ..datavars import BuilderError
+from ..variables.action import Actions 
 
 _ = lambda x: x
 setLocalTranslate('cl_builder3', sys.modules[__name__])
