@@ -66,6 +66,10 @@ class ClBuilderProfileAction(Action):
          'method': 'Builder.invalidateVariables("cl_builder_profile_storage")',
          'depend': Tasks.has('migrate_repository')
          },
+        {'name': 'check_datavars',
+         'error': _("Profile not found in master"),
+         'condition': lambda Get: not Get('cl_builder_profile_datavars')
+         },
         {'name': 'drop_binhosts',
          'method': 'Builder.drop_binhosts(cl_builder_profile_datavars)'
          },
@@ -83,7 +87,7 @@ class ClBuilderProfileAction(Action):
          'tasks': [
              {'name': 'sync_reps',
               'foreach': 'cl_builder_profile_sync_rep',
-              'message': __("Syncing the {eachvar:capitalize} repository"),
+              'message': __("Checking the {eachvar:capitalize} repository"),
               'method': 'Builder.syncRepositories(eachvar)',
               },
              {'name': 'regen_cache',
